﻿#include "TileAtlas.hpp"

TileAtlas TileAtlas::defaultAtlas()
{
	TileAtlas atlas(sf::Vector2u{16, 16}, sf::Vector2u{16, 16}, ASSETS_PATH "/default_tilemap.png");
	atlas.sprite.setTexture(atlas.texture);
	atlas.sprite.setTextureRect(sf::IntRect({0, 0}, {static_cast<int>(atlas.tile_size.x), static_cast<int>(atlas.tile_size.y)}));
	return atlas;
}

void TileAtlas::set(uint32_t x, uint32_t y)
{
	if (x >= tile_count.x || y >= tile_count.y) return;
	sprite.setTextureRect(sf::IntRect({static_cast<int>(x * tile_size.x), static_cast<int>(y * tile_size.y)}, sf::Vector2<int>(tile_size)));
}

TileAtlas::TileAtlas(const sf::Vector2u tile_size, const sf::Vector2u tile_count, const std::filesystem::path& path) :
	tile_size(tile_size), tile_count(tile_count), sprite(texture) { load(path); }

TileAtlas::TileAtlas(sf::Vector2u tile_size, sf::Vector2u tile_count) : tile_size(tile_size), tile_count(tile_count), sprite(texture)
{
}

void TileAtlas::load(const std::filesystem::path& path)
{
	if (!texture.loadFromFile(path))
	{
		throw std::runtime_error("TileAtlas: [Loading] Could not load tilemap -> Fatal");
	}
	sprite.setTexture(texture);
	sprite.setTextureRect(sf::IntRect({0, 0}, {static_cast<int>(tile_size.x), static_cast<int>(tile_size.y)}));
}

void TileAtlas::draw(sf::RenderTarget& target, const sf::RenderStates states) const
{
	if (texture.getSize().x == 0 || texture.getSize().y == 0)
	{
		return;
	}
	target.draw(sprite, states);
}